netapp_ontap.resources.web API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.web`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

# Overview

You can use this API to update web services configurations and to retrieve current configurations.

## Retrieving the current web services configuration

The cluster web GET API retrieves the current cluster-wide configuration.

## Updating the current web services configuration

The cluster web PATCH API updates the current cluster-wide configuration. Once updated, ONTAP restarts the web services to apply the changes. When updating the certificate, the certificate UUID of an existing certificate known to ONTAP must be provided. The certificate must be of type "server". A "client-ca" certificate must be installed on ONTAP to enable "client_enabled". The following fields can be used to update the cluster-wide configuration:

- enabled
- http_port
- https_port
- http_enabled
- csrf.protection_enabled
- csrf.token.concurrent_limit
- csrf.token.idle_timeout
- csrf.token.max_timeout
- certificate.uuid
- client_enabled
- ocsp_enabled
- hsts.enabled
- hsts.max_age

## Examples

### Retrieving the cluster-wide web services configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Web

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Web()
        resource.get()
        print(resource)

Try it out

    Web(
        {
            "_links": {"self": {"href": "/api/cluster/web"}},
            "ocsp_enabled": False,
            "csrf": {
                "token": {"concurrent_limit": 500, "max_timeout": 650, "idle_timeout": 900},
                "protection_enabled": True,
            },
            "http_port": 80,
            "https_port": 443,
            "http_enabled": False,
            "hsts": {"max_age": 31536000, "enabled": True},
            "state": "online",
            "client_enabled": False,
            "certificate": {
                "_links": {
                    "self": {
                        "href": "/api/security/certificates/a3bb219d-4382-1fe0-9c06-1070568ea23d"
                    }
                },
                "name": "cert1",
                "uuid": "a3bb219d-4382-1fe0-9c06-1070568ea23d",
            },
            "enabled": True,
        }
    )

### Updating the cluster-wide web services configuration

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Web

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Web()
        resource.https_port = 446
        resource.csrf = {"token": {"concurrent_limit": 600}}
        resource.patch()

## Classes

`class Web (*args, **kwargs)`

  Allows interaction with Web objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the web services configuration.

    ### Related ONTAP commands

    - `system services web show`
    - `security ssl show`

    ### Learn more

    - `DOC /cluster/web`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the web services configuration.

    ### Related ONTAP commands

    - `system services web modify`
    - `security ssl modify`

    ### Learn more

    - `DOC /cluster/web`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class WebSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Web object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `certificate: WebCertificate GET POST PATCH`

    Certificate used by cluster and node management interfaces for TLS connection requests.

  `client_enabled: bool GET POST PATCH`

    Indicates whether client authentication is enabled.

  `csrf: WebCsrf GET POST PATCH`

    The csrf field of the web.

  `enabled: bool GET POST PATCH`

    Indicates whether remote clients can connect to the web services.

  `hsts: WebHsts GET POST PATCH`

    The hsts field of the web.

  `http_enabled: bool GET POST PATCH`

    Indicates whether HTTP is enabled.

  `http_port: Size GET POST PATCH`

    HTTP port for cluster-level web services.

  `https_port: Size GET POST PATCH`

    HTTPS port for cluster-level web services.

  `links: SelfLink GET`

    The links field of the web.

  `ocsp_enabled: bool GET POST PATCH`

    Indicates whether online certificate status protocol verification is enabled.

  `per_address_limit: Size GET POST PATCH`

    The number of connections that can be processed concurrently from the same remote address.

    Example: 42

  `state: str GET`

    State of the cluster-level web services.

    Valid choices:

    - offline
    - partial
    - mixed
    - online
    - unclustered
  `wait_queue_capacity: Size GET POST PATCH`

    The maximum size of the wait queue for connections exceeding the per-address-limit.